==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebForOfDataChangingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebForOfDataChangingEventArgsDetailDescription } from "./WebForOfDataChangingEventArgsDetailDescription";
/**
 * @hidden
 */
var WebForOfDataChangingEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebForOfDataChangingEventArgsDetailDescriptionMetadata, _super);
    function WebForOfDataChangingEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebForOfDataChangingEventArgsDetailDescriptionMetadata.a == null) {
            WebForOfDataChangingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfDataChangingEventArgsDetailDescriptionMetadata.c(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
    };
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ForOfDataChangingEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("ContainerSize", "Number:double");
    };
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.d = function (a) {
        WebForOfDataChangingEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebForOfDataChangingEventArgsDetail", function () { return new WebForOfDataChangingEventArgsDetailDescription(); });
        a.z("WebForOfDataChangingEventArgsDetail", WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
    };
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.$t = markType(WebForOfDataChangingEventArgsDetailDescriptionMetadata, 'WebForOfDataChangingEventArgsDetailDescriptionMetadata');
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.a = null;
    return WebForOfDataChangingEventArgsDetailDescriptionMetadata;
}(Base));
export { WebForOfDataChangingEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebForOfDataChangingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebForOfDataChangingEventArgsDetailDescription } from "./WebForOfDataChangingEventArgsDetailDescription";
/**
 * @hidden
 */
var WebForOfDataChangingEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebForOfDataChangingEventArgsDetailDescriptionMetadata, _super);
    function WebForOfDataChangingEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebForOfDataChangingEventArgsDetailDescriptionMetadata.a == null) {
            WebForOfDataChangingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfDataChangingEventArgsDetailDescriptionMetadata.c(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
    };
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ForOfDataChangingEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("ContainerSize", "Number:double");
    };
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.d = function (a) {
        WebForOfDataChangingEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebForOfDataChangingEventArgsDetail", function () { return new WebForOfDataChangingEventArgsDetailDescription(); });
        a.ab("WebForOfDataChangingEventArgsDetail", WebForOfDataChangingEventArgsDetailDescriptionMetadata.a);
    };
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.$t = markType(WebForOfDataChangingEventArgsDetailDescriptionMetadata, 'WebForOfDataChangingEventArgsDetailDescriptionMetadata');
    WebForOfDataChangingEventArgsDetailDescriptionMetadata.a = null;
    return WebForOfDataChangingEventArgsDetailDescriptionMetadata;
}(Base));
export { WebForOfDataChangingEventArgsDetailDescriptionMetadata };
